from setuptools import setup

setup(
    name='gros_client',  # 需要打包的名字,即本模块要发布的名字
    version='1.0.6',  # 版本
    description='init',
    author='jax',
    author_email='ming.li@fftai.com',
    license='MIT'
)
